pub struct UpdatePreparedStatementFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdatePreparedStatement.
Updates a prepared statement.
Implementations
Sourceimpl UpdatePreparedStatementFluentBuilder
impl UpdatePreparedStatementFluentBuilder
Sourcepub fn as_input(&self) -> &UpdatePreparedStatementInputBuilder
pub fn as_input(&self) -> &UpdatePreparedStatementInputBuilder
Access the UpdatePreparedStatement as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdatePreparedStatementOutput, SdkError<UpdatePreparedStatementError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdatePreparedStatementOutput, SdkError<UpdatePreparedStatementError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdatePreparedStatementOutput, UpdatePreparedStatementError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdatePreparedStatementOutput, UpdatePreparedStatementError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn statement_name(self, input: impl Into<String>) -> Self
pub fn statement_name(self, input: impl Into<String>) -> Self
The name of the prepared statement.
Sourcepub fn set_statement_name(self, input: Option<String>) -> Self
pub fn set_statement_name(self, input: Option<String>) -> Self
The name of the prepared statement.
Sourcepub fn get_statement_name(&self) -> &Option<String>
pub fn get_statement_name(&self) -> &Option<String>
The name of the prepared statement.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The workgroup for the prepared statement.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The workgroup for the prepared statement.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The workgroup for the prepared statement.
Sourcepub fn query_statement(self, input: impl Into<String>) -> Self
pub fn query_statement(self, input: impl Into<String>) -> Self
The query string for the prepared statement.
Sourcepub fn set_query_statement(self, input: Option<String>) -> Self
pub fn set_query_statement(self, input: Option<String>) -> Self
The query string for the prepared statement.
Sourcepub fn get_query_statement(&self) -> &Option<String>
pub fn get_query_statement(&self) -> &Option<String>
The query string for the prepared statement.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the prepared statement.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the prepared statement.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the prepared statement.